baseObjects.ProtocolMap

|  | ## Cheshire3 Object Model: Class ProtocolMap

Module baseObjects :: Class ProtocolMap

## Class ProtocolMap
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           ProtocolMap

Known Subclasses:
  protocolMap.ZeerexProtocolMap

Protocol maps map from an incoming query type to internal indexes based on some specification.
Instance Methods

resolve_index(self, session, data) Given a query, resolve it and return the index object to be used.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

protocol |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### resolve_index(self, session, data) | source code
Given a query, resolve it and return the index object to be used.

Class Variable Details

    ### protocol Value:
        ''